==> dde-network-core_2.0.56.1.tar.xz: BUILD/src/translations/dde-network-core_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>QObject</name>
    <message>
        <source>None</source>
        <translation>Žádná</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key</source>
        <translation>WEP klíč 40/128 bitů</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobní</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelované TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Chráněné EAP</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailInterRealize</name>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailNMRealize</name>
    <message>
        <source>automatic</source>
        <translation>automaticky</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Ověřování</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Získávání IP adresy</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Střet IP adres</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepodařilo se</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Získávání adresy</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Drátová síť %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrátová síť %1</translation>
    </message>
</context>
</TS>

==> dde-network-core_2.0.60.tar.xz: BUILD/src/translations/dde-network-core_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>QObject</name>
    <message>
        <source>None</source>
        <translation>Žádná</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key</source>
        <translation>WEP klíč 40/128 bitů</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobní</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelované TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Chráněné EAP</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailInterRealize</name>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailNMRealize</name>
    <message>
        <source>automatic</source>
        <translation>automaticky</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Ověřování se</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Získávání IP adresy</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Kolize IP adres</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepodařilo se</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Získávání adresy</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Drátová síť %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrátová síť %1</translation>
    </message>
</context>
</TS>
